TILESIZE = 32 -- dimensions of a cell (and tile also)

QUAD_WIDTH = 5
QUAD_HEIGHT = 5

ENEMIES_PER_QUAD = 5
ROCKS_PER_QUAD = 2

local myPlane = Plane.new(QUAD_WIDTH, QUAD_HEIGHT) -- our plane (fancy collection of grids)

-- generate enemies
for q = 1, 4 do
  for i = 1, ENEMIES_PER_QUAD do
	local x, y = myPlane:getPosition(q, 1)
    print("enemy created at " .. x .. ", " .. y)
  end
end

-- generate rocks
for q = 1, 4 do
  for i = 1, ROCKS_PER_QUAD do
	local x, y = myPlane:getPosition(q, 2)
    print("rock created at " .. x .. ", " .. y)
  end
end

-- draw everything to the stage
local canvas = RenderTarget.new(TILESIZE * QUAD_WIDTH * 2, TILESIZE * QUAD_HEIGHT * 2)

local dirt = Bitmap.new( Texture.new("dirt.png", true) ) -- brushes for drawing on canvas
local enemy = Bitmap.new( Texture.new("enemy.png", true) )
local rock = Bitmap.new( Texture.new("rock.png", true) )

local plane = myPlane:getPlane()
for r = 0, (QUAD_HEIGHT * 2) - 1 do
  for c = 0, (QUAD_WIDTH * 2) - 1 do
    local cell = plane[(r * (QUAD_WIDTH * 2)) + c + 1] -- get next cell
    if cell == 0 then -- determine which brush to draw
      brush = dirt
    elseif cell == 1 then
      brush = enemy
    else
      brush = rock
    end
    brush:setPosition(c * TILESIZE, r * TILESIZE) -- set position and draw brush
    canvas:draw(brush)
  end
end

local display = Bitmap.new(canvas) -- show our world
stage:addChild(display)

local p1 = Pixel.new(0x000000, 0.25, TILESIZE * QUAD_WIDTH * 2, 2) -- horizontal quad divider
p1:setPosition(0, TILESIZE * QUAD_HEIGHT - 1)
stage:addChild(p1)

local p2 = Pixel.new(0x000000, 0.25, 2, TILESIZE * QUAD_HEIGHT * 2) -- vertical quad divider
p2:setPosition(TILESIZE * QUAD_WIDTH - 1, 0)
stage:addChild(p2)
